/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef USERADD_H
#define USERADD_H

#include <QRegExp>
#include <QDialog>
#include <QRadioButton>
#include <QTextEdit>
#include <QLabel>
#include <QLayout>
#include <QCheckBox>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QProcess>
#include <QDir>
//added in segatex7.8.10
#include <unistd.h>


class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class Useradd: public QDialog
{
	Q_OBJECT
public:
	Useradd(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:

private slots:
	void useradd_clicked();
	void userdel_clicked();
	void readfromfile_clicked();
	void useradd_base_process(QString username_str, QString passwordEditLineEdit_str);
	void userdel_base_process(QString username_str);
	void readFromStdout();
	void processExited();
	void readFromOutputFile();
private:
	QProcess *process;
	QTextEdit *textEdit1;
	QLabel *usernameLabel;
	QLabel *passwordLabel;
	QLabel *password2Label;
	QVBoxLayout *firstLayout;
	QHBoxLayout *leftLayout;
	QVBoxLayout *rightLayout;
	QHBoxLayout *mainLayout;
	QLineEdit *usernameEditLineEdit;
	QLineEdit *passwordEditLineEdit;
	QLineEdit *password2EditLineEdit;
	QPushButton *useraddButton;
	QPushButton *userdelButton;
	QPushButton *readfromfileButton;
	QPushButton *closeButton;
	QString username_str;
	QString username_str_ps1;
	QString username_str_ps2;
	QString passwordEditLineEdit_str;
	QString password2EditLineEdit_str;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif
